Learn R Programming

rocrateR (version 0.0.1)

.validate_bagit_manifest: Validate BagIt declaration

Description

Validate BagIt declaration

Usage

.validate_bagit_manifest(path, algo = "sha512", manifest_suffix = "manifest")

Value

A list with status and errors identified.

Arguments

path

String with full path to a compressed file contain an RO-Crate bag, see bag_rocrate for details. Alternatively, a path to a directory containing an RO-Crate bag.

algo

String with algorithm used to generate the RO-Crate bag (default: "sha512"). See digest for more details.

manifest_suffix

String with suffix for the manifest file (default: "manifest").