add_author: Add an author to an RO-Crate

View source: R/utils-rocrate.R

add_authorR Documentation

Add an author to an RO-Crate

Description

This helper creates an author entity and if affiliation is provided, then creates an organisation entity for the user's affiliation.

Usage

add_author(
  rocrate,
  name,
  orcid = NULL,
  affiliation = NULL,
  ror = NULL,
  set_author = TRUE
)

Arguments

rocrate

RO-Crate object, see rocrate.

name

Author's name.

orcid

Optional, ORCID identifier, for details see https://orcid.org.

affiliation

Optional, author's organisation.

ror

Optional, ROR identifier for the affiliation, for details see https://ror.org.

set_author

Logical, used to indicate if the current user should be set as the author of the RO-Crate.

Value

Updated RO-Crate object.


rocrateR documentation built on April 9, 2026, 1:06 a.m.