is_rocrate: Check if object is an RO-Crate

is_rocrateR Documentation

Check if object is an RO-Crate

Description

Check if object is an RO-Crate

Usage

is_rocrate(rocrate, strict = FALSE, error = TRUE)

Arguments

rocrate

RO-Crate object, see rocrate.

strict

Boolean to indicate if stricter checks should be done (e.g., check profile specification).

error

Boolean to indicate if the function should throw an error, if any errors are found (default: TRUE).

Value

Boolean flag with RO-Crate validity.

Examples

basic_crate <- rocrateR::rocrate()

# check if the new crate is valid
basic_crate |>
  rocrateR::is_rocrate()

rocrateR documentation built on April 9, 2026, 1:06 a.m.