| rocrate | R Documentation |
Create a new RO-Crate object. This object includes basic skeleton for the
RO-Crate metadata descriptor (ro-crate-metadata.json) file, as described
in the official documentation: https://w3id.org/ro/crate/1.2/ >
Root Data Entity.
rocrate(
...,
context = "https://w3id.org/ro/crate/1.2/context",
conformsTo = gsub("\\/context$", "\\1", context),
datePublished = Sys.Date(),
description = "",
license = "http://spdx.org/licenses/CC-BY-4.0",
name = ""
)
... |
Optional entities to include in the RO-Crate (e.g., author). |
context |
String with URL to the version of the RO-Crate specification to use. The context brings the defined terms into the metadata document (default: https://w3id.org/ro/crate/1.2/context). |
conformsTo |
String with URL to the version of the RO-Crate
specification which this object conforms to. Conformance declares which
RO-Crate conventions of using those terms are being followed
(default: URL formed by |
datePublished |
String (or Date object) with the date in which the RO-Crate was published (default: current date). |
description |
String with description for the root entity (default: empty string). |
license |
String with URL (permalinks are preferred, but not required) to license to be used for the overall RO-Crate. See the following resources for license choices: https://spdx.org/licenses and/or https://github.com/spdx/license-list-data/tree/main/jsonld (default: CC-BY-4.0: Creative Commons Attribution 4.0 International). |
name |
String with a name/title for the root entity (default: empty string). |
RO-Crate object, list with an additional class, rocrate.
rocrateR::rocrate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.