| summary.rocrate | R Documentation |
Provides a summary of the contents of an RO-Crate, including the number of entities, files and basic metadata information.
## S3 method for class 'rocrate'
summary(object, ...)
object |
An object of class "rocrate". |
... |
Additional arguments (unused). |
An object of class "summary.rocrate".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.