Validate BagIt declaration
.validate_bagit_manifest(path, algo = "sha512", manifest_suffix = "manifest")A list with status and errors identified.
String with full path to a compressed file contain an RO-Crate bag, see bag_rocrate for details. Alternatively, a path to a directory containing an RO-Crate bag.
String with algorithm used to generate the RO-Crate bag
(default: "sha512"). See digest for more details.
String with suffix for the manifest file (default:
"manifest").