View source: R/utils-rocrate.R
| add_author | R Documentation |
This helper creates an author entity and if affiliation is provided, then
creates an organisation entity for the user's affiliation.
add_author(
rocrate,
name,
orcid = NULL,
affiliation = NULL,
ror = NULL,
set_author = TRUE
)
rocrate |
RO-Crate object, see rocrate. |
name |
Author's name. |
orcid |
Optional, ORCID identifier, for details see https://orcid.org. |
affiliation |
Optional, author's organisation. |
ror |
Optional, ROR identifier for the affiliation, for details see https://ror.org. |
set_author |
Logical, used to indicate if the current user should be set as the author of the RO-Crate. |
Updated RO-Crate object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.