View source: R/utils-rocrate.R
| add_dataset | R Documentation |
This helper converts an R object (typically a data.frame) into a
dataset inside the RO-Crate. The object is stored in the content
field and written to disk when calling extract_content() or
bag_rocrate(write_content = TRUE).
add_dataset(
rocrate,
file_id,
data = NULL,
name = NULL,
description = NULL,
encodingFormat = "text/csv"
)
rocrate |
RO-Crate object, see rocrate. |
file_id |
Filename for the dataset file. |
data |
R object to store (typically a |
name |
Dataset name. |
description |
Optional dataset description. |
encodingFormat |
MIME type (default |
Use this when you want to register a dataset file or directory as a formal Dataset entity inside the RO-Crate metadata.
Updated RO-Crate object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.