| add_entity_value | R Documentation |
Add entity value to RO-Crate, under entity with @id = {id}, using the
pair {key}-{value} within @graph.
add_entity_value(rocrate, id, key, value, overwrite = FALSE, verbose = FALSE)
rocrate |
RO-Crate object, see rocrate. |
id |
String with the ID of the RO-Crate entity within |
key |
String with the |
value |
String with the |
overwrite |
Boolean flag to indicate if the existing value (if any),
should be overwritten (default: |
verbose |
Boolean flag to indicate if status messages should be hidden
(default: |
Updated RO-Crate object.
basic_crate <- rocrate()
# create entity for an organisation
organisation_uol <- rocrateR::entity(
"https://ror.org/04xs57h96",
type = "Organization",
name = "University of Liverpool",
url = "http://www.liv.ac.uk"
)
# create an entity for a person
person_rvd <- rocrateR::entity(
"https://orcid.org/0000-0001-5036-8661",
type = "Person",
name = "Roberto Villegas-Diaz",
affiliation = list(`@id` = organisation_uol$`@id`)
)
basic_crate_v2 <- basic_crate |>
rocrateR::add_entity_value(
id = "./",
key = "author",
value = list(`@id` = person_rvd$`@id`)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.