Learn R Programming

rocrateR (version 0.0.1)

bag_rocrate: Bag the contents of an RO-Crate

Description

Bag the contents of an RO-Crate using the BagIt file packaging format v1.0. For more details see the definition: tools:::Rd_expr_doi("10.17487/RFC8493")

Usage

bag_rocrate(x, ...)

# S3 method for character bag_rocrate(x, ..., output = x, force_bag = FALSE)

# S3 method for rocrate bag_rocrate(x, ..., path, output = path, overwrite = FALSE, force_bag = FALSE)

Value

String with full path to the final RO-Crate bag.

Arguments

x

A string to a path containing at the very minimum an RO-Crate metadata descriptor file, ro-crate-metadata.json. Alternatively, an object with the rocrate class.

...

Additional parameters, see below.

output

String with path where the RO-Crate bag will be stored (default: x - same path as the input value).

force_bag

Boolean flag to indicate whether the force the creation of a 'bag' even if not all the files were successfully bagged (default: FALSE ~ check if all the files were copied successfully).

path

String with path to the root of the RO-Crate.

overwrite

Boolean flag to indicate if the RO-Crate metadata descriptor file should be overwritten if already inside path (default: FALSE).

See Also

Other bag_rocrate: is_rocrate_bag(), unbag_rocrate()