| is_rocrate | R Documentation |
Check if object is an RO-Crate
is_rocrate(rocrate, strict = FALSE, error = TRUE)
rocrate |
RO-Crate object, see rocrate. |
strict |
Boolean to indicate if stricter checks should be done (e.g., check profile specification). |
error |
Boolean to indicate if the function should throw an error, if
any errors are found (default: |
Boolean flag with RO-Crate validity.
basic_crate <- rocrateR::rocrate()
# check if the new crate is valid
basic_crate |>
rocrateR::is_rocrate()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.