Learn R Programming

rocrateR (version 0.0.1)

is_rocrate_bag: Check if path points to a valid RO-Crate bag

Description

Check if path points to a valid RO-Crate bag

Usage

is_rocrate_bag(path, algo = "sha512", bagit_version = "1.0")

Value

Returns invisibly the RO-Crate pointed by path.

Arguments

path

String with full path to a compressed file contain an RO-Crate bag, see bag_rocrate for details. Alternatively, a path to a directory containing an RO-Crate bag.

algo

String with algorithm used to generate the RO-Crate bag (default: "sha512"). See digest for more details.

bagit_version

String with version of BagIt used to generate the RO-Crate bag (default: "1.0"). See tools:::Rd_expr_doi("10.17487/RFC8493") for more details.

See Also

Other bag_rocrate: bag_rocrate(), unbag_rocrate()