Check if path points to a valid RO-Crate bag
is_rocrate_bag(path, algo = "sha512", bagit_version = "1.0")Returns invisibly the RO-Crate pointed by path.
String with full path to a compressed file contain an RO-Crate bag, see bag_rocrate for details. Alternatively, a path to a directory containing an RO-Crate bag.
String with algorithm used to generate the RO-Crate bag
(default: "sha512"). See digest for more details.
String with version of BagIt used to generate the
RO-Crate bag (default: "1.0").
See tools:::Rd_expr_doi("10.17487/RFC8493") for more details.
Other bag_rocrate:
bag_rocrate(),
unbag_rocrate()