Learn R Programming

rocrateR (version 0.0.1)

unbag_rocrate: 'Unbag' (extract) RO-Crate packed with BagIt

Description

'Unbag' (extract) RO-Crate packed with BagIt

Usage

unbag_rocrate(path, output = dirname(path), quiet = FALSE)

Value

String with path to root of the RO-Crate, invisibly.

Arguments

path

String with path to compressed file containing an RO-Crate bag.

output

String with target path where the contents will be extracted (default: dirname(path) - same directory as input path).

quiet

Boolean flag to indicate if messages should be suppressed (default: FALSE - display messages).

See Also

Other bag_rocrate: bag_rocrate(), is_rocrate_bag()