'Unbag' (extract) RO-Crate packed with BagIt
unbag_rocrate(path, output = dirname(path), quiet = FALSE)String with path to root of the RO-Crate, invisibly.
String with path to compressed file containing an RO-Crate bag.
String with target path where the contents will be extracted
(default: dirname(path) - same directory as input path).
Boolean flag to indicate if messages should be suppressed
(default: FALSE - display messages).
Other bag_rocrate:
bag_rocrate(),
is_rocrate_bag()